@@ -26,12 +26,15 @@ SH_Literal = SH.term('Literal')
 SH_BlankNodeOrIRI = SH.term('BlankNodeOrIRI')
 SH_BlankNodeORLiteral = SH.term('BlankNodeOrLiteral')
 SH_IRIOrLiteral = SH.term('IRIOrLiteral')
+SH_ConstraintComponent = SH.term('ConstraintComponent')
 SH_SHACLFunction = SH.term('SHACLFunction')
 SH_SPARQLFunction = SH.term('SPARQLFunction')
 SH_SPARQLRule = SH.term('SPARQLRule')
 SH_TripleRule = SH.term('TripleRule')
 SH_SPARQLTarget = SH.term('SPARQLTarget')
 SH_SPARQLTargetType = SH.term('SPARQLTargetType')
+SH_JSTarget = SH.term('JSTarget')
+SH_JSTargetType = SH.term('JSTargetType')
 
 # predicates
 RDF_type = RDF.term('type')
@@ -89,4 +92,8 @@ SH_nodes = SH.term('nodes')
 SH_union = SH.term('union')
 SH_intersection = SH.term('intersection')
 SH_datatype = SH.term('datatype')
+SH_nodeKind = SH.term('nodeKind')
 SH_optional = SH.term('optional')
+SH_js = SH.term('js')
+SH_jsFunctionName = SH.term('jsFunctionName')
+SH_jsLibrary = SH.term('jsLibrary')
