@@ -3,7 +3,7 @@
 import logging
 
 from decimal import Decimal
-from typing import TYPE_CHECKING, List, Optional, Set, Tuple, Union
+from typing import TYPE_CHECKING, List, Optional, Set, Tuple, Type, Union
 
 from rdflib import RDF, BNode, Literal, URIRef
 
@@ -15,6 +15,9 @@ from .consts import (
     SH_deactivated,
     SH_description,
     SH_inversePath,
+    SH_jsFunctionName,
+    SH_JSTarget,
+    SH_JSTargetType,
     SH_message,
     SH_name,
     SH_oneOrMorePath,
@@ -34,8 +37,8 @@ from .consts import (
     SH_zeroOrOnePath,
 )
 from .errors import ConstraintLoadError, ConstraintLoadWarning, ReportableRuntimeError, ShapeLoadError
+from .helper import get_query_helper_cls
 from .pytypes import GraphLike
-from .sparql_query_helper import SPARQLQueryHelper
 
 
 if TYPE_CHECKING:
@@ -233,16 +236,33 @@ class Shape(object):
     def advanced_target(self):
         custom_targets = set(self.sg.objects(self.node, SH_target))
         result_set = dict()
+        if self.sg.js_enabled:
+            from pyshacl.extras.js.target import JSTarget
+
+            use_JSTarget: Union[bool, Type] = JSTarget
+        else:
+            use_JSTarget = False
+
         for c in custom_targets:
             ct = dict()
             selects = list(self.sg.objects(c, SH_select))
             has_select = len(selects) > 0
+            fn_names = list(self.sg.objects(c, SH_jsFunctionName))
+            has_fnname = len(fn_names) > 0
             is_types = set(self.sg.objects(c, RDF_type))
             if has_select or (SH_SPARQLTarget in is_types):
                 ct['type'] = SH_SPARQLTarget
+                SPARQLQueryHelper = get_query_helper_cls()
                 qh = SPARQLQueryHelper(self, c, selects[0], deactivated=self._deactivated)
                 qh.collect_prefixes()
                 ct['qh'] = qh
+            elif has_fnname or (SH_JSTarget in is_types):
+                if use_JSTarget:
+                    ct['type'] = SH_JSTarget
+                    ct['targeter'] = use_JSTarget(self.sg, c)
+                else:
+                    #  Found JSTarget, but JS is not enabled in PySHACL. Ignore this target.
+                    pass
             else:
                 found_tt = None
                 for t in is_types:
@@ -254,9 +274,12 @@ class Shape(object):
                 if not found_tt:
                     msg = "None of these types match a TargetType: {}".format(" ".join(is_types))
                     raise ShapeLoadError(msg, "https://www.w3.org/TR/shacl-af/#SPARQLTargetType")
-                ct['type'] = SH_SPARQLTargetType
                 bound_tt = found_tt.bind(self, c)
-                ct['qt'] = bound_tt
+                ct['type'] = bound_tt.shacl_constraint_class()
+                if ct['type'] == SH_SPARQLTargetType:
+                    ct['qt'] = bound_tt
+                elif ct['type'] == SH_JSTargetType:
+                    ct['targeter'] = bound_tt
             result_set[c] = ct
         return result_set
 
@@ -307,14 +330,22 @@ class Shape(object):
                     qh = at['qh']
                     select = qh.apply_prefixes(qh.select_text)
                     results = data_graph.query(select, initBindings=None)
+                    if not results or len(results.bindings) < 1:
+                        continue
+                    for r in results:
+                        t = r['this']
+                        found_node_targets.add(t)
+                elif at['type'] in (SH_JSTarget, SH_JSTargetType):
+                    results = at['targeter'].find_targets(data_graph)
+                    for r in results:
+                        found_node_targets.add(r)
                 else:
                     results = at['qt'].find_targets(data_graph)
-                if not results or len(results.bindings) < 1:
-                    continue
-                for r in results:
-                    t = r['this']
-                    found_node_targets.add(t)
-
+                    if not results or len(results.bindings) < 1:
+                        continue
+                    for r in results:
+                        t = r['this']
+                        found_node_targets.add(t)
         return found_node_targets
 
     @classmethod
@@ -487,14 +518,24 @@ class Shape(object):
         # Lazy import here to avoid an import loop
         from .constraints import ALL_CONSTRAINT_PARAMETERS, CONSTRAINT_PARAMETERS_MAP
 
-        parameters = (p for p, v in self.sg.predicate_objects(self.node) if p in ALL_CONSTRAINT_PARAMETERS)
+        if self.sg.js_enabled:
+            search_parameters = ALL_CONSTRAINT_PARAMETERS.copy()
+            constraint_map = CONSTRAINT_PARAMETERS_MAP.copy()
+            from pyshacl.extras.js.constraint import JSConstraint, SH_js
+
+            search_parameters.append(SH_js)
+            constraint_map[SH_js] = JSConstraint
+        else:
+            search_parameters = ALL_CONSTRAINT_PARAMETERS
+            constraint_map = CONSTRAINT_PARAMETERS_MAP
+        parameters = (p for p, v in self.sg.predicate_objects(self.node) if p in search_parameters)
         reports = []
         focus_value_nodes = self.value_nodes(target_graph, focus)
         non_conformant = False
         done_constraints = set()
         run_count = 0
         _evaluation_path.append(self)
-        constraint_components = [CONSTRAINT_PARAMETERS_MAP[p] for p in iter(parameters)]
+        constraint_components = [constraint_map[p] for p in iter(parameters)]
         for constraint_component in constraint_components:
             if constraint_component in done_constraints:
                 continue
@@ -526,7 +567,4 @@ class Shape(object):
             non_conformant = non_conformant or (not _is_conform)
             reports.extend(_r)
             run_count += 1
-        # TODO: Can these two lines be completely removed?
-        #  if run_count < 1:
-        #      raise RuntimeError("A SHACL Shape should have at least one parameter or attached property shape.")
         return (not non_conformant), reports
