@@ -33,13 +33,16 @@ shacl = """\
 """
 
 
-dataGraph = rdflib.Graph().parse(data=data, format='ttl')
-#print(dataGraph.serialize(format='ttl').decode('utf8'))
+def schema_org():
+    dataGraph = rdflib.Graph().parse(data=data, format='ttl')
+    #print(dataGraph.serialize(format='ttl').decode('utf8'))
 
-shaclGraph = rdflib.Dataset()
-shaclGraph.parse(data=shacl, format='ttl')
+    shaclGraph = rdflib.Dataset()
+    shaclGraph.parse(data=shacl, format='ttl')
 
-report = validate(dataGraph, shacl_graph=shaclGraph, abort_on_error=False, meta_shacl=False, debug=False, advanced=True, do_owl_imports=True)
+    report = validate(dataGraph, shacl_graph=shaclGraph, abort_on_error=False, inference='both', meta_shacl=False, debug=False, advanced=True, do_owl_imports=True)
 
-print(report[2])
+    print(report[2])
 
+if __name__ == "__main__":
+    schema_org()
